@@ -1,7 +1,7 @@
 use serde::{Deserialize, Serialize};
 
 #[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
+#[serde(rename_all = "camelCase")]
 pub struct UserPermissions {
-    #[serde(rename = "summaryPermissions")]
     pub summary_permissions: String,
 }
